@@ -14,9 +14,8 @@ from rasterio.warp import transform_geom
 from rio_tiler import constants
 from rio_tiler.errors import InvalidBandName
 from rio_tiler.io import COGReader, MultiBandReader
-
-from ... import get_object
-from ..utils import s2_sceneid_parser
+from rio_tiler_pds.sentinel.utils import s2_sceneid_parser
+from rio_tiler_pds.utils import get_object
 
 default_l1c_bands = (
     "B01",
@@ -88,7 +87,7 @@ class S2L1CReader(MultiBandReader):
         band = band if len(band) == 3 else f"B0{band[-1]}"
 
         if band not in self.bands:
-            raise InvalidBandName(f"{band} is not valid")
+            raise InvalidBandName(f"{band} is not valid.\nValid bands: {self.bands}")
 
         prefix = self._prefix.format(**self.scene_params)
         return f"{self._scheme}://{self._hostname}/{prefix}/{band}.jp2"
@@ -184,7 +183,7 @@ class S2L2AReader(S2L1CReader):
         band = band if len(band) == 3 else f"B0{band[-1]}"
 
         if band not in self.bands:
-            raise InvalidBandName(f"{band} is not valid")
+            raise InvalidBandName(f"{band} is not valid.\nValid bands: {self.bands}")
 
         prefix = self._prefix.format(**self.scene_params)
         res = self._get_resolution(band)
@@ -223,13 +222,15 @@ class S2L2ACOGReader(MultiBandReader):
 
     _scheme: str = "s3"
     _hostname: str = "sentinel-cogs"
-    _prefix: str = "sentinel-s2-{_levelLow}-cogs/{_utm}/{lat}/{sq}/{acquisitionYear}/{_month}/{scene}"
+    _prefix: str = "sentinel-s2-{_levelLow}-cogs/{_utm}/{lat}/{sq}/{acquisitionYear}/{_month}/S{sensor}{satellite}_{_utm}{lat}{sq}_{acquisitionYear}{acquisitionMonth}{acquisitionDay}_{num}_{processingLevel}"
 
     def __attrs_post_init__(self):
         """Fetch item.json and get bounds and bands."""
         self.scene_params = s2_sceneid_parser(self.sceneid)
 
-        cog_sceneid = self.scene_params["scene"]
+        cog_sceneid = "S{sensor}{satellite}_{_utm}{lat}{sq}_{acquisitionYear}{acquisitionMonth}{acquisitionDay}_{num}_{processingLevel}".format(
+            **self.scene_params
+        )
         prefix = self._prefix.format(**self.scene_params)
         self.stac_item = json.loads(
             get_object(
@@ -246,14 +247,14 @@ class S2L2ACOGReader(MultiBandReader):
         band = band if len(band) == 3 else f"B0{band[-1]}"
 
         if band not in self.bands:
-            raise InvalidBandName(f"{band} is not valid")
+            raise InvalidBandName(f"{band} is not valid.\nValid bands: {self.bands}")
 
         prefix = self._prefix.format(**self.scene_params)
         return f"{self._scheme}://{self._hostname}/{prefix}/{band}.tif"
 
 
 def S2COGReader(sceneid: str, **kwargs: Any) -> S2L2ACOGReader:
-    """Sentinel-2 JPEG2000 readers."""
+    """Sentinel-2 COG readers."""
     scene_params = s2_sceneid_parser(sceneid)
     level = scene_params["processingLevel"]
     if level == "L2A":
@@ -263,7 +264,7 @@ def S2COGReader(sceneid: str, **kwargs: Any) -> S2L2ACOGReader:
 
 
 def S2JP2Reader(sceneid: str, **kwargs: Any) -> Union[S2L2AReader, S2L1CReader]:
-    """Sentinel-2 COG readers."""
+    """Sentinel-2 JPEG2000 readers."""
     scene_params = s2_sceneid_parser(sceneid)
     level = scene_params["processingLevel"]
     if level == "L2A":
